@@ -104,10 +104,8 @@ class TestECU(unittest.TestCase):
         self.message_queue = queue.Queue()
         self.message_thread = threading.Thread(target=self._async_can_feeder)
         self.message_thread.start()
-        
-        self.ecu = j1939.ElectronicControlUnit()
         # redirect the send_message from the can bus to our simulation
-        self.ecu.send_message = self._send_message
+        self.ecu = j1939.ElectronicControlUnit(send_message=self._send_message)
         # install a fake-CA to accept all messages
         ca = AcceptAllCA(None)
         self.ecu.add_ca(controller_application = ca)
@@ -268,7 +266,7 @@ class TestECU(unittest.TestCase):
         Its length is 20 Bytes.
         """
         self.can_messages = [
-            (TestECU.MsgType.CANTX, 0x18EC9B90, [16, 20, 0, 3, 255, 0, 223, 0], 0.0),        # TP.CM RTS 1
+            (TestECU.MsgType.CANTX, 0x18EC9B90, [16, 20, 0, 3, 1, 0, 223, 0], 0.0),          # TP.CM RTS 1
             (TestECU.MsgType.CANRX, 0x1CEC909B, [17, 1, 1, 255, 255, 0, 223, 0], 0.0),       # TP.CM CTS 1
             (TestECU.MsgType.CANTX, 0x1CEB9B90, [1, 1, 2, 3, 4, 5, 6, 7], 0.0),              # TP.DT 1
             (TestECU.MsgType.CANRX, 0x1CEC909B, [17, 1, 2, 255, 255, 0, 223, 0], 0.0),       # TP.CM CTS 2
